@@ -6,7 +6,7 @@ use File::ShareDir qw(dist_dir);
 use File::Spec;
 use File::Find;
 use File::Spec::Functions qw(catdir catfile rel2abs);
-use File::Temp ();
+use File::Temp;
 use ExtUtils::CBuilder;
 
 =head1 NAME
@@ -15,11 +15,11 @@ Alien::PNG - building, finding and using PNG binaries
 
 =head1 VERSION
 
-Version 0.3_01
+Version 0.1
 
 =cut
 
-our $VERSION = '0.3_01';
+our $VERSION = '0.1';
 $VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
@@ -169,9 +169,8 @@ sub config
 {
   my $package = shift;
   my @params  = @_;
-  return _png_config_via_script(@params)          if Alien::PNG::ConfigData->config('script');
-  return _png_config_via_win32_pkgconfig(@params) if Alien::PNG::ConfigData->config('win32_pkgconfig');
-  return _png_config_via_config_data(@params)     if Alien::PNG::ConfigData->config('config');
+  return _png_config_via_script(@params)      if(Alien::PNG::ConfigData->config('script'));
+  return _png_config_via_config_data(@params) if(Alien::PNG::ConfigData->config('config'));
 }
 
 ### get version info from given header file
@@ -208,7 +207,7 @@ sub check_header {
   my ($package, @header) = @_;
   print STDERR "[$package] Testing header(s): " . join(', ', @header) . "\n";
   my $cb = ExtUtils::CBuilder->new(quiet => 1);
-  my ($fs, $src) = File::Temp::tempfile('aaXXXX', SUFFIX => '.c', UNLINK => 1);
+  my ($fs, $src) = File::Temp->tempfile('XXXXaa', SUFFIX => '.c', UNLINK => 1);
   my $inc = '';
   $inc .= "#include <$_>\n" for @header;  
   syswrite($fs, <<MARKER); # write test source code
@@ -256,32 +255,6 @@ sub _png_config_via_script
   return $val;
 }
 
-sub _png_config_via_win32_pkgconfig
-{
-  my $param     = shift;
-  my @add_libs  = @_;
-  my $devnull   = File::Spec->devnull();
-  my $pkgconfig = Alien::PNG::ConfigData->config('win32_pkgconfig');
-  return unless ($pkgconfig && ($param =~ /[a-z0-9_]*/i));
-
-  my ($prefix) = grep { /\/perl\/lib$/ } @INC;
-  return unless $prefix;
-  $prefix              =~ s/\/perl\/lib$/\/c/;
-  $pkgconfig->{prefix} = $prefix;
-
-  if (ref $pkgconfig->{$param} eq 'ARRAY') {
-    return map { s/\@PrEfIx\@/$prefix/g; } @{$pkgconfig->{$param}};
-  }
-  elsif (ref $pkgconfig->{$param} eq 'HASH') {
-    map { $pkgconfig->{$param}{$_} =~ s/\@PrEfIx\@/$prefix/g } keys %{$pkgconfig->{$param}};
-  }
-  else {
-    $pkgconfig->{$param} =~ s/\@PrEfIx\@/$prefix/g;
-  }
-
-  $pkgconfig->{$param};
-}
-
 sub _png_config_via_config_data
 {
   my $param    = shift;
